@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """One-class SVM detector. Implemented on scikit-learn library.
 """
-# Author: Yue Zhao <yuezhao@cs.toronto.edu>
+# Author: Yue Zhao <zhaoy@cmu.edu>
 # License: BSD 2 clause
 
 from __future__ import division
@@ -23,7 +23,7 @@ class OCSVM(BaseDetector):
 
     The implementation is based on libsvm.
     See http://scikit-learn.org/stable/modules/svm.html#svm-outlier-detection
-    and :cite:`ma2003time`.
+    and :cite:`scholkopf2001estimating`.
 
     Parameters
     ----------
@@ -55,7 +55,7 @@ class OCSVM(BaseDetector):
     tol : float, optional
         Tolerance for stopping criterion.
 
-    shrinking : boolean, optional
+    shrinking : bool, optional
         Whether to use the shrinking heuristic.
 
     cache_size : float, optional
@@ -74,12 +74,6 @@ class OCSVM(BaseDetector):
         the proportion of outliers in the data set. Used when fitting to
         define the threshold on the decision function.
 
-    random_state : int, RandomState instance or None, optional (default=None)
-        The seed of the pseudo random number generator to use when shuffling
-        the data.  If int, random_state is the seed used by the random number
-        generator; If RandomState instance, random_state is the random number
-        generator; If None, the random number generator is the RandomState
-        instance used by `np.random`.
 
     Attributes
     ----------
@@ -121,8 +115,7 @@ class OCSVM(BaseDetector):
 
     def __init__(self, kernel='rbf', degree=3, gamma='auto', coef0=0.0,
                  tol=1e-3, nu=0.5, shrinking=True, cache_size=200,
-                 verbose=False, max_iter=-1, contamination=0.1,
-                 random_state=None):
+                 verbose=False, max_iter=-1, contamination=0.1):
         super(OCSVM, self).__init__(contamination=contamination)
         self.kernel = kernel
         self.degree = degree
@@ -134,18 +127,26 @@ class OCSVM(BaseDetector):
         self.cache_size = cache_size
         self.verbose = verbose
         self.max_iter = max_iter
-        self.random_state = random_state
 
     def fit(self, X, y=None, sample_weight=None, **params):
-        """Fit detector. y is optional for unsupervised methods.
+        """Fit detector. y is ignored in unsupervised methods.
 
         Parameters
         ----------
         X : numpy array of shape (n_samples, n_features)
             The input samples.
 
-        y : numpy array of shape (n_samples,), optional (default=None)
-            The ground truth of the input samples (labels).
+        y : Ignored
+            Not used, present for API consistency by convention.
+
+        sample_weight : array-like, shape (n_samples,)
+            Per-sample weights. Rescale C per sample. Higher weights
+            force the classifier to put more emphasis on these points.
+
+        Returns
+        -------
+        self : object
+            Fitted estimator.
         """
         # validate inputs X and y (optional)
         X = check_array(X)
@@ -160,8 +161,7 @@ class OCSVM(BaseDetector):
                                      shrinking=self.shrinking,
                                      cache_size=self.cache_size,
                                      verbose=self.verbose,
-                                     max_iter=self.max_iter,
-                                     random_state=self.random_state)
+                                     max_iter=self.max_iter)
         self.detector_.fit(X=X, y=y, sample_weight=sample_weight,
                            **params)
 
