@@ -441,9 +441,10 @@ def _get_sklearn_version():  # pragma: no cover
     """
 
     sklearn_version = str(sklearn.__version__)
-    if int(sklearn_version.split(".")[1]) < 19 or int(
-            sklearn_version.split(".")[1]) > 24:
-        raise ValueError("Sklearn version error")
+    # print(sklearn_version)
+    # if int(sklearn_version.split(".")[1]) < 19 or int(
+    #         sklearn_version.split(".")[1]) > 24:
+    #     raise ValueError("Sklearn version error")
 
     return int(sklearn_version.split(".")[1])
 
@@ -544,3 +545,42 @@ def generate_indices(random_state, bootstrap, n_population, n_samples):
                                              random_state=random_state)
 
     return indices
+
+# todo: add a test for it in test_utility.py
+def get_optimal_n_bins(X, upper_bound=None, epsilon=1):
+    """ Determine optimal number of bins for a histogram using the Birge 
+    Rozenblac method (see :cite:`birge2006many` for details.)
+     
+    See  https://doi.org/10.1051/ps:2006001 
+     
+    Parameters 
+    ---------- 
+    X : array-like of shape (n_samples, n_features) 
+        The samples to determine the optimal number of bins for. 
+         
+    upper_bound :  int, default=None 
+        The maximum value of n_bins to be considered. 
+        If set to None, np.sqrt(X.shape[0]) will be used as upper bound. 
+         
+    epsilon : float, default = 1 
+        A stabilizing term added to the logarithm to prevent division by zero. 
+         
+    Returns 
+    ------- 
+    optimal_n_bins : int 
+        The optimal value of n_bins according to the Birge Rozenblac method 
+    """
+    if upper_bound is None:
+        upper_bound = int(np.sqrt(X.shape[0]))
+
+    n = X.shape[0]
+    maximum_likelihood = np.zeros((upper_bound - 1, 1))
+
+    for i, b in enumerate(range(1, upper_bound)):
+        histogram, _ = np.histogram(X, bins=b)
+
+        maximum_likelihood[i] = np.sum(
+            histogram * np.log(b * histogram / n + epsilon) - (
+                        b - 1 + np.power(np.log(b), 2.5)))
+
+    return np.argmax(maximum_likelihood) + 1
